@@ -6,8 +6,6 @@ import celery
 from celery.utils.log import get_task_logger
 from celery import signals
 
-PY2 = sys.version_info[0] == 2
-
 
 @signals.celeryd_init.connect
 def configure_worker(conf=None, **kwargs):
@@ -18,10 +16,7 @@ def configure_worker(conf=None, **kwargs):
 @signals.task_failure.connect
 def log_exception(**kwargs):
     logger = logging.getLogger("celery.task")
-    if PY2:
-        einfo = str(kwargs['einfo']).decode('utf8')
-    else:
-        einfo = str(kwargs['einfo'])
+    einfo = str(kwargs['einfo'])
     logger.critical(u"unhandled exception:\n%s", einfo)
 
 
@@ -36,9 +31,9 @@ def setup_cubicweb_logging(conf=None, **kwargs):
         if logname == 'celery' or logname.startswith('celery.'):
             # Logger name 'celery' is reserved
             continue
-        if(logall
-           or logname.startswith('cubes')
-           or logname.startswith('cubicweb')):
+        if logall \
+           or logname.startswith('cubes') \
+           or logname.startswith('cubicweb'):
             get_task_logger(logname)
 
 
@@ -47,7 +42,7 @@ def redirect_stdouts(logger):
     old_outs = sys.stdout, sys.stderr
     try:
         app = celery.current_app
-        rlevel = app.conf.CELERY_REDIRECT_STDOUTS_LEVEL
+        rlevel = app.conf.worker_redirect_stdouts_level
         app.log.redirect_stdouts_to_logger(logger, rlevel)
         yield
     finally:
