@@ -3,7 +3,7 @@
 modname = 'cw_celerytask_helpers'
 distname = 'cw-celerytask-helpers'
 
-numversion = (0, 11, 0)
+numversion = (1, 0, 1)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -13,14 +13,12 @@ description = 'Worker side helpers for cubicweb-celerytask'
 web = 'https://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
-    'celery': '>=4,<5',
+    'celery': '~= 5.0',
     'redis': None,
-    'six': None,
 }
 
 classifiers = [
-    'Development Status :: 3 - Alpha',
     'Intended Audience :: Developers',
-    'Programming Language :: Python :: 2',
-    'Programming Language :: Python :: 2.7',
+    'Programming Language :: Python :: 3',
+    'Programming Language :: Python :: 3 :: Only',
 ]
