@@ -34,4 +34,4 @@ def postrun(task_id, task, *args, **kwargs):
 
 @celery.signals.task_revoked.connect
 def task_revoked(request, *args, **kwargs):
-    monitor_task(request.task_id, request.task.name)
+    monitor_task(request.id, request.task)
