@@ -12,7 +12,7 @@ def get_log_key(task_id):
 def get_redis_client():
     conf = celery.current_app.conf
     url = conf.get('CUBICWEB_CELERYTASK_REDIS_URL')
-    BROKER_TRANSPORT_OPTIONS = conf.get('BROKER_TRANSPORT_OPTIONS')
+    BROKER_TRANSPORT_OPTIONS = conf.get('broker_transport_options')
     if (url and url.startswith('redis-sentinel://')
             and 'sentinels' in BROKER_TRANSPORT_OPTIONS):
         from redis.sentinel import Sentinel
